==> system-api-7.0.3-sources.jar: cn/stylefeng/roses/kernel/system/api/pojo/user/UserSelectTreeNode.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.system.api.pojo.user;

import cn.hutool.core.collection.IterUtil;
import cn.stylefeng.roses.kernel.rule.enums.TreeNodeEnum;
import cn.stylefeng.roses.kernel.rule.tree.factory.node.DefaultTreeNode;
import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 用户选择树节点封装
 * <p>
 * 默认的根节点id是-1，名称是根节点
 *
 * @author liuhanqing
 * @date 2021/1/15 13:36
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UserSelectTreeNode extends DefaultTreeNode {

    /**
     * 节点类型：org: 机构  user: 用户
     */
    private String nodeType;

    /**
     * 节点值
     */
    private String value;

    /**
     * 是否被选中
     */
    private Boolean selected = false;

    /**
     * 是否禁用
     */
    private Boolean disabled = false;

    public Boolean getDisabled() {
        if (this.disabled) {
            return true;
        }
        if (TreeNodeEnum.ORG.getCode().equals(nodeType) && IterUtil.isEmpty(this.getChildren())) {
            return true;
        }
        return this.disabled;
    }

}

==> system-api-7.1.3-sources.jar: cn/stylefeng/roses/kernel/system/api/pojo/user/UserSelectTreeNode.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.system.api.pojo.user;

import cn.hutool.core.collection.IterUtil;
import cn.stylefeng.roses.kernel.rule.enums.TreeNodeEnum;
import cn.stylefeng.roses.kernel.rule.tree.factory.node.DefaultTreeNode;
import cn.stylefeng.roses.kernel.scanner.api.annotation.field.ChineseDescription;
import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 用户选择树节点封装
 * <p>
 * 默认的根节点id是-1，名称是根节点
 *
 * @author liuhanqing
 * @date 2021/1/15 13:36
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class UserSelectTreeNode extends DefaultTreeNode {

    /**
     * 节点类型：org: 机构  user: 用户
     */
    @ChineseDescription("节点类型：org: 机构  user: 用户")
    private String nodeType;

    /**
     * 节点值
     */
    @ChineseDescription("节点值")
    private String value;

    /**
     * 是否被选中
     */
    @ChineseDescription("是否被选中")
    private Boolean selected = false;

    /**
     * 是否禁用
     */
    @ChineseDescription("是否禁用")
    private Boolean disabled = false;

    public Boolean getDisabled() {
        if (this.disabled) {
            return true;
        }
        if (TreeNodeEnum.ORG.getCode().equals(nodeType) && IterUtil.isEmpty(this.getChildren())) {
            return true;
        }
        return this.disabled;
    }

}
